@@ -38,6 +38,18 @@
 #include "../../plugins/plugin.h"
 
 
+/*
+ * Returns description of hook.
+ *
+ * Note: result must be freed after use.
+ */
+
+char *
+hook_command_get_description (struct t_hook *hook)
+{
+    return strdup (HOOK_COMMAND(hook, command));
+}
+
 /*
  * Searches for a command hook in list.
  *
