@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2017 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2011-2022 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef WEECHAT_GUI_FOCUS_H
@@ -45,5 +45,9 @@ extern struct t_gui_focus_info *gui_focus_get_info (int x, int y);
 extern void gui_focus_free_info (struct t_gui_focus_info *focus_info);
 extern struct t_hashtable *gui_focus_to_hashtable (struct t_gui_focus_info *focus_info,
                                                    const char *key);
+extern struct t_hashtable *gui_focus_info_hashtable_gui_focus_info_cb (const void *pointer,
+                                                                       void *data,
+                                                                       const char *info_name,
+                                                                       struct t_hashtable *hashtable);
 
 #endif /* WEECHAT_GUI_FOCUS_H */
