@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2006-2017 Adam Saponara <as@php.net>
- * Copyright (C) 2017-2021 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2017-2022 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -126,6 +126,7 @@ PHP_FUNCTION(weechat_color);
 PHP_FUNCTION(weechat_print);
 PHP_FUNCTION(weechat_print_date_tags);
 PHP_FUNCTION(weechat_print_y);
+PHP_FUNCTION(weechat_print_y_date_tags);
 PHP_FUNCTION(weechat_log_print);
 PHP_FUNCTION(weechat_hook_command);
 PHP_FUNCTION(weechat_hook_completion);
@@ -154,6 +155,7 @@ PHP_FUNCTION(weechat_hook_set);
 PHP_FUNCTION(weechat_unhook);
 PHP_FUNCTION(weechat_unhook_all);
 PHP_FUNCTION(weechat_buffer_new);
+PHP_FUNCTION(weechat_buffer_new_props);
 PHP_FUNCTION(weechat_buffer_search);
 PHP_FUNCTION(weechat_buffer_search_main);
 PHP_FUNCTION(weechat_current_buffer);
